@@ -18,4 +18,4 @@
         $('.rte p:empty').remove();
         $('.rte hr').remove();
     });
-})(jQuery.noConflict());
\ No newline at end of file
+})(django.jQuery);
\ No newline at end of file
